@@ -21,6 +21,7 @@ from serial.tools import hexlify_codec
 import time
 from pathlib import Path
 import re
+import datetime
 
 # pylint: disable=wrong-import-order,wrong-import-position
 
@@ -520,11 +521,15 @@ class Miniterm(object):
         try:
             while self.alive and self._reader_alive:
                 # read all that is there or wait for one byte
-                data = self.serial.read(self.serial.in_waiting or 1)
+                data = self.serial.read(1)
                 if data:
                     if self.raw:
                         self.console.write_bytes(data)
                         self.logfile.write(data.decode())
+                        if data == b'\n':
+                            timestamp = '{0:%H:%M:%S} '.format(datetime.datetime.now())
+                            self.console.write_bytes(timestamp.encode())
+                            self.logfile.write(timestamp)
                     else:
                         text = self.rx_decoder.decode(data)
                         for transformation in self.rx_transformations:
